@@ -158,7 +158,7 @@ public class SMS {
 			// execute test call
             result = (Map<?, ?>) client.execute("samurai.ClientIdentify", params);
 			// System.err.println(result);
-		} catch (final Exception e) {
+		} catch (Exception e) {
 			 wassendingsuccessfull = false;
 			 this.senderrormessage = e.getMessage();
 			 LOG.error("API error occured while executing samurai.ClientIdentify",e);
@@ -182,15 +182,15 @@ public class SMS {
 		try {
 			// execute SMS sending......
             result = (Map<?, ?>) client.execute("samurai.SessionInitiateMulti", params);
-		} catch (final Exception e) {
+		} catch (Exception e) {
 			wassendingsuccessfull = false;
 			this.senderrormessage = e.getMessage();
 			LOG.error("API error occured while executing samurai.SessionInitiateMulti",e);
 		}
 
 		 //check if sending was OK
-		 if(result!=null){
-			 if(result.get("StatusCode").toString().trim().equalsIgnoreCase("200")){
+		 if (result!=null){
+			 if (result.get("StatusCode").toString().trim().equalsIgnoreCase("200")){
 				 wassendingsuccessfull = true;
 			 }else{
 				 wassendingsuccessfull = false;
@@ -238,7 +238,7 @@ public class SMS {
 		boolean validNumber = true;
 
 		// number contains more than one "+"
-		if (to.indexOf("+") >= 0) {
+		if (to.indexOf('+') >= 0) {
 			validNumber = false;
 		}
 
